@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Handler::XGoogleDKIM;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20200106'; # VERSION
+our $VERSION = '2.20200107'; # VERSION
 
 use Data::Dumper;
 use English qw{ -no_match_vars };
@@ -71,7 +71,8 @@ sub header_callback {
         my $resolver = $self->get_object('resolver');
         if ( $selector && $domain ) {
             my $lookup = $selector.'._domainkey.'.$domain;
-            $resolver->bgsend( $lookup, 'TXT' );
+            eval{ $resolver->bgsend( $lookup, 'TXT' ) };
+            $self->handle_exception( $@ );
             $self->dbgout( 'DNSEarlyLookup', "$lookup TXT", LOG_DEBUG );
         }
     }
@@ -322,7 +323,7 @@ Mail::Milter::Authentication::Handler::XGoogleDKIM
 
 =head1 VERSION
 
-version 2.20200106
+version 2.20200107
 
 =head1 DESCRIPTION
 
